#################
Integration tests
#################

These scripts provide end-to-end tests of Lander with real documents.
These scripts don't upload to LSST the Docs but they do exercise the command line interface, configuration, document parsing, metadata.jsonld generation, and HTML generation.

.. code-block:: bash

   test_ldm151.bash

You can also activate these scripts from the ``make`` file at the root of the repo.
